@@ -10,11 +10,10 @@ class Client():
 
 
   def __init__(self, app_id):
-    h = REAL_TIME_LOG_BASE_URL
     if app_id:
-      self.url = h + app_id
+      self.url = REAL_TIME_LOG_BASE_URL + app_id
     else:
-      res = requests.get(h)
+      res = requests.get(REAL_TIME_LOG_BASE_URL)
       self.url = res.url
 
 
